pub fn git_diff_analysis(
cx: &AnalysisContext<'_>,
strategy: GitDiffStrategy,
) -> DifftestsResult<AnalysisResult>Expand description
Performs a git diff analysis on the diff between the current HEAD and the working tree.
pub fn git_diff_analysis(
cx: &AnalysisContext<'_>,
strategy: GitDiffStrategy,
) -> DifftestsResult<AnalysisResult>Performs a git diff analysis on the diff between the current HEAD and the working tree.