Function git_diff_analysis_from_commit

pub fn git_diff_analysis_from_commit(
    cx: &AnalysisContext<'_>,
    strategy: GitDiffStrategy,
    commit: Oid,
) -> DifftestsResult<AnalysisResult>
Performs a git diff analysis on the diff between tree of the given commit and the working tree.