Enum DiscoverIndexPathResolver

pub enum DiscoverIndexPathResolver {
    Remap {
        from: PathBuf,
        to: PathBuf,
    },
    Custom {
        f: Box<dyn Fn(&Path) -> Option<PathBuf>>,
    },
}
A resolver for test index data file paths.

Examples


let resolver = DiscoverIndexPathResolver::Remap {from: "foo".into(), to: "bar".into()};

assert_eq!(resolver.resolve(Path::new("foo/bar/baz")), Some(PathBuf::from("bar/bar/baz")));
assert_eq!(resolver.resolve(Path::new("bar/baz")), None);

Variants



Remap

Remaps the index path from the given from path to the given to path.

Fields

from: PathBuf

The path to strip from the index path.

to: PathBuf

The path to append to the stripped index path.



Custom

A custom remapping function.

Fields

f: Box<dyn Fn(&Path) -> Option<PathBuf>>

The remapping function.

Implementations

Source

impl DiscoverIndexPathResolver

pub fn resolve(&self, p: &Path) -> Option<PathBuf>

Resolves the index path from the given Difftest directory.