Struct ExportProfdataConfig

pub struct ExportProfdataConfig {
    pub ignore_registry_files: bool,
    pub other_binaries: Vec<PathBuf>,
}
The configuration to use when exporting a .profdata file into a .json file.

Fields

ignore_registry_files: bool

Whether to ignore files from the cargo registry.

other_binaries: Vec<PathBuf>

Other binaries to include in the export.

By default, only the test binary is included (via the CoreTestDesc’s bin_path field), but if the test has spawned some other child process (as often happens when testing binaries), and they were profiled, the paths to those binaries should be passed here.