Struct IndexDataCompilerConfig

pub struct IndexDataCompilerConfig {
    pub ignore_registry_files: bool,
    pub remove_bin_path: bool,
    pub index_filename_converter: Box<dyn FnMut(&Path) -> PathBuf>,
    pub accept_file: Box<dyn FnMut(&Path) -> bool>,
    pub index_size: IndexSize,
}
Configuration for the TestIndex::index function.

Fields

ignore_registry_files: bool

Whether to ignore files in the cargo registry.

remove_bin_path: bool

Whether or not to remove the binary path from the index.

index_filename_converter: Box<dyn FnMut(&Path) -> PathBuf>

A conversion function for the file names in the index. This is useful for converting absolute paths to paths relative to the repository root for example.

accept_file: Box<dyn FnMut(&Path) -> bool>

A function that determines whether a file should be indexed. This is useful for excluding files that are not part of the project, such as files in the cargo registry.

index_size: IndexSize

The desired size of the index.

This is useful for reducing the size of the index, at the cost of losing some information.

Refer to IndexSize for more information.