pub struct IndexRegion {
pub l1: usize,
pub c1: usize,
pub l2: usize,
pub c2: usize,
pub count: usize,
pub file_id: usize,
}Expand description
A region in a TestIndex.
Fields
l1: usizeThe line number of the first line of the region.
c1: usizeThe column number of the first column of the region.
l2: usizeThe line number of the last line of the region.
c2: usizeThe column number of the last column of the region.
count: usizeThe number of times the region was executed.
file_id: usizeThe index of the file in the TestIndex.